.. _white_light_step:

============================
White Light Curve Generation
============================

.. toctree::
   :maxdepth: 2

   description.rst
   arguments.rst
   reference_files.rst

.. automodapi:: jwst.white_light
